@@ -11,6 +11,7 @@
 #define ANALYSIS_H
 
 #include <QtCore>
+#include <QTime>
 #include "movelist.h"
 
 class Board;
@@ -65,6 +66,16 @@ public:
     bool bestMove() const;
 
     bool isAlreadyMate() const;
+
+    int elapsedTimeMS() const;
+    void setElapsedTimeMS(int elapsedTimeMS);
+
+    bool getEndOfGame() const;
+    void setEndOfGame(bool value);
+
+    bool getBookMove() const;
+    void setBookMove(bool bookMove);
+
 private:
     int m_numpv;
     int m_msec;
@@ -72,8 +83,11 @@ private:
     int m_depth;
     int m_score;
     bool m_bestMove;
+    bool m_endOfGame;
+    bool m_bookMove;
     quint64 m_nodes;
     MoveList m_variation;
+    int m_elapsedTimeMS;
 };
 
 #endif // ANALYSIS_H
