@@ -992,7 +992,7 @@ bool BitBoard::fromGoodFen(const QString& qfen, bool chess960)
     {
         return false;
     }
-    c = fen[++i];
+    ++i;
 
     // Castling Rights
     c = fen[++i];
@@ -1119,7 +1119,7 @@ bool BitBoard::fromGoodFen(const QString& qfen, bool chess960)
         }
     }
     epFile2Square();
-    c = fen[++i];
+    ++i;
 
     // Half move clock
     c = fen[++i];
@@ -1130,7 +1130,7 @@ bool BitBoard::fromGoodFen(const QString& qfen, bool chess960)
     if (c=='-')
     {
         m_halfMoves = 0; // Workaround for some lazy generators
-        c = fen[++i]; // Eat ws
+        ++i; // Eat ws
     }
     else
     {
@@ -3380,3 +3380,14 @@ bool BitBoard::from64Char(const QString& qcharboard)
 
     return true;
 }
+
+int BitBoard::numAttackedBy(const unsigned int color, Square square) const
+{
+    int num = 0;
+    num += countSetBits(bb_PawnAttacks[color ^ 1][square] & m_pawns & m_occupied_co[color]);
+    num += countSetBits(knightAttacksFrom(square) & m_knights & m_occupied_co[color]);
+    num += countSetBits(bishopAttacksFrom(square) & (m_bishops | m_queens) & m_occupied_co[color]);
+    num += countSetBits(rookAttacksFrom(square) & (m_rooks | m_queens) & m_occupied_co[color]);
+    num += countSetBits(kingAttacksFrom(square) & m_kings & m_occupied_co[color]);
+    return num;
+};
