@@ -14,6 +14,7 @@
 #include "filter.h"
 #include "game.h"
 #include "index.h"
+#include "refcount.h"
 
 #include <QMutex>
 #include <QString>
@@ -30,7 +31,7 @@
 class Database : public QObject
 {
     Q_OBJECT
-
+    SUPPORTS_REFCOUNTING
 public:
     /** Standard constructor. */
     Database();
@@ -94,6 +95,7 @@ public:
     virtual bool deleted(GameId gameId) const;
 
     virtual bool IsClipboard() const { return false; }
+
 signals:
     /** Signal emitted when some progress is done. */
     void progress(int);
