@@ -112,6 +112,9 @@ protected:
     /** Processes messages from the chess engine */
     virtual void processMessage(const QString& message) = 0;
 
+    /** Log error message into the logging stream */
+    virtual void logError(QString errMsg);
+
     /** Sends a message to the chess engine */
     void send(const QString& message);
 
@@ -146,6 +149,9 @@ public:
     QList<EngineOptionData> m_options;
     OptionValueList m_mapOptionValues;
 
+    bool hasOption(QString name) const;
+    bool getOption(QString name, EngineOptionData &result);
+
 private:
     QString m_name;
     QString	m_command;
@@ -158,7 +164,6 @@ private:
 
 public:
     static void setAllowEngineOutput(bool allow);
-
 protected:
     static bool s_allowEngineOutput;
 };
