@@ -13,6 +13,7 @@
 
 #include <QObject>
 #include "board.h"
+#include "gameid.h"
 #include "movelist.h"
 #include "nag.h"
 #include "result.h"
@@ -53,8 +54,6 @@ class SaveRestoreMoveCompact;
 typedef QHash<QString, QString> TagMap;
 typedef QHashIterator<QString, QString> TagMapIterator;
 
-typedef quint32 GameId;
-
 class Game : public QObject
 {
     Q_OBJECT
@@ -86,23 +85,26 @@ public :
         PreviousMove
     };
 
-    static const QRegExp egt;
-    static const QRegExp clk;
-    static const QRegExp emt;
-    static const QRegExp csl;
-    static const QRegExp cal;
+    static const char* s_egt;
+    static const char* s_clk;
+    static const char* s_emt;
+    static const char* s_csl;
+    static const char* s_cal;
 
     Game();
     Game(const Game& game);
     Game& operator=(const Game& game);
     virtual ~Game();
+
+    void mountBoard();
+    void unmountBoard();
+    int mountRefCount;
+
     // **** Querying game information ****
-    /** compare tags */
-    int compareTags(const Game& game) const;
-    /** compare moves */
-    int compareMoves(const Game& game) const;
-    /** compare games */
-    int compare(const Game& game) const;
+    /** compare game moves and annotations */
+    int isEqual(const Game& game) const;
+    /** compare game moves and annotations */
+    int isBetterOrEqual(const Game& game) const;
     /** @return current position */
     const Board& board() const;
     /** @return current position in FEN */
@@ -130,7 +132,7 @@ public :
     /** @return annotation at move at node @p moveId. */
     QString specAnnotation(const QRegExp &r, MoveId moveId = CURRENT_MOVE) const;
     /** @return time annotation (either egt or clock) at move at node @p moveId. */
-    QString timeAnnotation(MoveId moveId = CURRENT_MOVE) const;
+    QString timeAnnotation(MoveId moveId = CURRENT_MOVE, Position position = AfterMove) const;
 
     /** @return @p true if a move can have annotation before the move. */
     bool canHaveStartAnnotation(MoveId moveId = CURRENT_MOVE) const;
@@ -164,6 +166,7 @@ public :
     bool setArrowAnnotation(QString arrowAnnotation, MoveId moveId = CURRENT_MOVE);
 
     /** Adds a nag to move at node @p moveId */
+    bool dbAddNag(Nag nag, MoveId moveId = CURRENT_MOVE);
     bool addNag(Nag nag, MoveId moveId = CURRENT_MOVE);
     /** Sets nags for move at node @p moveId */
     bool setNags(NagSet nags, MoveId moveId = CURRENT_MOVE);
@@ -214,6 +217,7 @@ public :
     void moveToStart();
     /** Moves to the end of the game */
     void moveToEnd();
+    bool dbMoveToEnd();
     /** Moves by given ply, returns actual ply reached */
     int moveByPly(int diff);
     /** Moves to the position corresponding to the given move id */
@@ -223,6 +227,7 @@ public :
     int forward(int count = 1);
     /** Move back the given number of moves, returns actual number of moves undone */
     int backward(int count = 1);
+    int dbBackward(int count = 1);
     /** Moves forward if the next move matches (from,to,promotionPiece) */
     bool findNextMove(Square from, Square to, PieceType promotionPiece = None);
     bool findNextMove(Move m);
@@ -292,10 +297,8 @@ public :
     void truncateVariation(Position position = AfterMove);
     /** Removes all tags and moves */
     void clear();
-    /** Set the game start position */
-    void dbSetStartingBoard(const Board& startingBoard);
     /** Set the game start position from FEN. */
-    void dbSetStartingBoard(const QString& fen);
+    void dbSetStartingBoard(const QString& fen, bool chess960 = false);
     /** set comment associated with game */
     void setGameComment(const QString& gameComment);
     /** Remove all variations */
@@ -317,8 +320,13 @@ public :
     /** Removes a tag */
     void removeTag(const QString& tag);
     /** Set the game result */
+    void dbSetResult(Result result);
     void setResult(Result result);
 
+    void dbSetChess960(bool b);
+    bool isChess960() const;
+    void setChess960(bool);
+
     // Searching
     /** Search game to see if given position exists, if it does return move id */
     MoveId findPosition(const Board& position) const;
@@ -356,12 +364,17 @@ public :
     void copyFromGame(const Game& g);
 
     int resultAsInt() const;
-    void setStartingBoard(const Board &startingBoard, QString text);
+    void setStartingBoard(const Board &startingBoard, QString text, bool chess960 = false);
 
     /** Removes the node at @p moveId */
     void removeNode(MoveId moveId = CURRENT_MOVE);
 
     MoveId lastMove() const;
+
+    bool positionRepetition3(const Board &board) const;
+    bool insufficientMaterial(const Board &b) const;
+
+
 protected:
     /** Find the point in the this game where @p otherGame fits in the next time.
         @retval Node from where the merging shall start in other game */
@@ -371,6 +384,8 @@ protected:
     /** Find the next illegal position in all variations and mainline moves after the current position, and cut the game from there */
     void truncateVariationAfterNextIllegalPosition();
 
+    void dbIndicateAnnotationsOnBoard(MoveId moveId);
+    bool positionRepetition(const Board &board);
 signals:
     void signalGameModified(bool,Game,QString);
     void signalMoveChanged();
@@ -400,6 +415,13 @@ private:
         void SetPly(short ply) { Q_ASSERT(m_ply<0x7FFF); m_ply = ply; }
         short Ply() const { return m_ply & 0x7FFF; }
         bool Removed() const { return (m_ply & 0x8000); }
+        inline bool operator==(const struct MoveNode& c) const
+        {
+            return (move == c.move &&
+                    variations == c.variations &&
+                    nags == c.nags &&
+                    m_ply == c.m_ply);
+        }
     };
 #pragma pack(pop)
 
@@ -412,7 +434,7 @@ private:
     /** Keeps the start position of the game */
     Board m_startingBoard;
     /** Keeps the current position of the game */
-    Board m_currentBoard;
+    Board* m_currentBoard;
 
     typedef QMap<MoveId, QString> AnnotationMap;
 
@@ -440,7 +462,7 @@ private:
 class SaveRestoreMove
 {
 public:
-    SaveRestoreMove(Game& game)
+    explicit SaveRestoreMove(Game& game)
     {
         m_saveGame = &game;
         m_saveMoveValue = game.currentMove();
@@ -457,7 +479,7 @@ private:
 class SaveRestoreMoveCompact
 {
 public:
-    SaveRestoreMoveCompact(Game& game)
+    explicit SaveRestoreMoveCompact(Game& game)
     {
         m_saveGame = &game;
         m_saveMoveValue = game.currentMove();
@@ -472,6 +494,5 @@ private:
     MoveId m_saveMoveValue;
 };
 
-
 #endif	// __GAME_H__
 
