@@ -3,6 +3,8 @@
 ****************************************************************************/
 
 #include <QtCore>
+#include <QFuture>
+#include <QtConcurrent/QtConcurrent>
 
 #include "polyglotdatabase.h"
 #include "board.h"
@@ -547,12 +549,19 @@ bool PolyglotDatabase::openForWriting(const QString &filename, int maxPly, int m
 void PolyglotDatabase::book_make(Database &db, volatile bool& breakFlag)
 {
     QMutexLocker m(mutex());
-    if (!breakFlag) add_database(db);
+    qDebug() << "Add Database";
+    if (!breakFlag) add_database(db, breakFlag);
+    qDebug() << "Spool map";
     if (!breakFlag) spool_map();
+    qDebug() << "Overflow correction";
     if (!breakFlag) overflow_correction();
+    qDebug() << "Filter Book";
     if (!breakFlag) book_filter();
+    qDebug() << "Sort Book";
     if (!breakFlag) book_sort();
+    qDebug() << "Save Book";
     if (!breakFlag) book_save();
+    qDebug() << "Close";
     close();
 }
 
@@ -628,13 +637,14 @@ book_entry* PolyglotDatabase::find_entry(const book_entry& entry)
 
 void PolyglotDatabase::update_entry(book_entry& entry, int result)
 {
+    QMutexLocker m(&mutex2);
     book_key key;
     key.key = entry.key;
     key.move = entry.move;
 
     book_value b = m_bookDictionary.value(key);
 
-    b.n++;
+    ++b.n;
     b.sum += result + 1;
 
     m_bookDictionary[key] = b;
@@ -767,12 +777,19 @@ void PolyglotDatabase::add_game(Game& g, int result)
     }
 }
 
-void PolyglotDatabase::add_database(Database& db)
+void PolyglotDatabase::add_database_chunk(Database* db, int start, int end, volatile bool* breakFlag)
 {
-    for(int i = 0; i < (int)db.count(); ++i)
+    int progressCount = 1 + end / 100;
+    for(int i = start; i < end; ++i)
     {
+        if (!start)
+        {
+            if ((i)%progressCount==0) emit progress((i)/progressCount);
+        }
+
+        if (*breakFlag) return;
         Game game;
-        if(db.loadGame(i, game))
+        if(db->loadGame(i, game))
         {
             int result = game.resultAsInt();
             if ((m_filterResult==0) || (m_filterResult != result))
@@ -782,3 +799,23 @@ void PolyglotDatabase::add_database(Database& db)
         }
     }
 }
+
+void PolyglotDatabase::add_database(Database& db, volatile bool& breakFlag)
+{
+    int maxThreads = QThread::idealThreadCount() - 1;
+    int n = db.count();
+    int junk = n/maxThreads;
+
+    RefKeeper m(db.refCounter());
+    qDebug()<<"Collect from database with" << maxThreads << "threads";
+    QFutureSynchronizer<void> synchronizer;
+    int start = 0;
+    for (int i=0; i<maxThreads; ++i)
+    {
+        int end = std::min(start + junk, n);
+        QFuture<void> future = QtConcurrent::run(this, &PolyglotDatabase::add_database_chunk, &db, start, end, &breakFlag);
+        synchronizer.addFuture(future);
+        start += junk;
+    }
+    synchronizer.waitForFinished();
+}
