@@ -133,6 +133,7 @@ public:
     void book_make(Database& db, volatile bool& breakFlag);
 
 signals:
+    void progress(int);
 
 public slots:
 
@@ -153,7 +154,8 @@ protected:
     void update_entry(book_entry &entry, int result);
     book_entry *find_entry(const book_entry &entry);
     void book_filter();
-    void add_database(Database &db);
+    void add_database(Database &db, volatile bool &breakFlag);
+    void add_database_chunk(Database* db, int start, int end, volatile bool *breakFlag);
     void add_game(Game &g, int result);
     bool get_move_entry(Move m, book_entry &entry) const;
     int get_promotion(Move m) const;
@@ -170,6 +172,7 @@ private:
     int m_filterResult;
     quint32 m_minGame;
     int m_maxPly;
+    QMutex mutex2;
 };
 
 #endif // POLYGLOTDATABASE_H
