@@ -26,7 +26,11 @@ void PolyglotWriter::run()
     m_destination->book_make(*m_source, m_break);
     if (!m_break)
     {
-        emit bookBuildFinished(m_out);
+        emit bookBuildFinished(m_out, this);
+    }
+    else
+    {
+        emit bookBuildError(m_out, this);
     }
     deleteLater();
 }
@@ -43,11 +47,12 @@ void PolyglotWriter::writeBookForDatabase(Database *src, const QString &out, int
     m_destination = new PolyglotDatabase();
     if (m_destination->openForWriting(out, maxPly, minGame, uniform, result, filterResult))
     {
+        connect(m_destination, SIGNAL(progress(int)), this, SIGNAL(progress(int)));
         start();
     }
     else
     {
-        emit bookBuildError(out);
+        emit bookBuildError(out, this);
         deleteLater();
     }
 }
