@@ -4,6 +4,11 @@
 
 #include "tags.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 bool isStandardTag(QString tag)
 {
     for(int i = 0; i < 7; ++i)
