@@ -27,7 +27,7 @@ TelnetClient::TelnetClient(QObject *parent)
     m_socket = new QTcpSocket(this);
     m_socket->setSocketOption(QAbstractSocket::LowDelayOption, 1);
     connect(m_socket, SIGNAL(readyRead()), this, SLOT(SlotReadData()));
-    connect(m_socket, SIGNAL(disconnected()), this, SLOT(SlotDisconnected()));
+    connect(m_socket, SIGNAL(disconnected()), this, SLOT(SlotSocketDisconnected()));
 
     m_extToolProcess = new QProcess(this);
     connect(m_extToolProcess, SIGNAL(readyRead()), SLOT(SlotReadTimesealData()));
@@ -42,6 +42,7 @@ TelnetClient::~TelnetClient()
         m_socket->close();
     }
     delete m_socket;
+    delete m_extToolProcess;
 }
 
 void TelnetClient::DispatchReadData(QByteArray bytes)
@@ -54,8 +55,6 @@ void TelnetClient::DispatchReadData(QByteArray bytes)
     data.remove(0x13);
     data.remove(0x07);
 
-    bool hasNetData = false;
-
     switch (m_state)
     {
         case 0:
@@ -104,6 +103,10 @@ void TelnetClient::DispatchReadData(QByteArray bytes)
                 ++m_state;
                 OnSessionStarted(guestName);
             }
+            else if (data.contains("Invalid"))
+            {
+                exitSession();
+            }
             break;
         }
         default:
@@ -112,7 +115,6 @@ void TelnetClient::DispatchReadData(QByteArray bytes)
             QStringList lines = data.split("\n", QString::SkipEmptyParts);
             if (lines.count() && !endsWithCR)
             {
-                hasNetData = true;
                 m_remainder = lines.back();
                 lines.pop_back();
             }
@@ -155,7 +157,13 @@ void TelnetClient::SlotReadData()
     }
 }
 
-void TelnetClient::SlotDisconnected()
+void TelnetClient::closeSession()
+{
+    exitSession();
+    emit disconnected();
+}
+
+void TelnetClient::SlotSocketDisconnected()
 {
     m_socket->close();
     emit disconnected();
