@@ -5,6 +5,13 @@
 #include "threadedguess.h"
 #include "guess.h"
 
+#include <QMetaType>
+
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 ThreadedGuess::ThreadedGuess()
 {
     m_dontGuess = false;
@@ -45,7 +52,8 @@ void ThreadedGuess::run()
     b.clearEnPassantSquare();
     Guess::MoveList moveList;
     Guess::Result sm = Guess::guessMove(qPrintable(b.toFen()),
-                                        (int) InvalidSquare,
+                                        b.chess960(), b.castlingRooks(),
+                                        Guess::NULL_SQUARE,
                                         moveList, 1500);
     if (!m_dontGuess)
     {
