@@ -9,6 +9,7 @@
  ***************************************************************************/
 
 #include "tristatetree.h"
+#include "query.h"
 
 #if defined(_MSC_VER) && defined(_DEBUG)
 #define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
@@ -40,7 +41,7 @@ TriStateTree::TriStateTree(const Query& query)
         {
             /* search == leaf node, add to stack & add to list of leaf nodes */
             m_nodes[element].m_state = Unknown;
-            m_nodes[element].m_operator = Search::NullOperator;
+            m_nodes[element].m_operator = Filter::NullOperator;
             m_nodes[element].m_parent = 0;
             m_nodes[element].m_leftChild = m_nodes[element].m_rightChild = 0;
             nodeStack[++stackTop] = &m_nodes[element];
@@ -52,7 +53,7 @@ TriStateTree::TriStateTree(const Query& query)
             m_nodes[element].m_state = Unknown;
             m_nodes[element].m_operator = query.searchOperator(element);
             m_nodes[element].m_parent = 0;
-            if(m_nodes[element].m_operator == Search::Not)
+            if(m_nodes[element].m_operator == Filter::Not)
             {
                 m_nodes[element].m_rightChild = 0;
             }
@@ -267,7 +268,7 @@ TriStateTree::State TriStateTree::update(Node* node)
     switch(node->m_operator)
     {
 
-    case Search::Not:
+    case Filter::Not:
         switch(leftState)
         {
         case Unknown:
@@ -282,7 +283,7 @@ TriStateTree::State TriStateTree::update(Node* node)
         }
         break;
 
-    case Search::And:
+    case Filter::And:
         if(leftState == False || rightState == False)
         {
             node->m_state = False;
@@ -297,7 +298,7 @@ TriStateTree::State TriStateTree::update(Node* node)
         }
         break;
 
-    case Search::Or:
+    case Filter::Or:
         if(leftState == True || rightState == True)
         {
             node->m_state = True;
@@ -312,7 +313,7 @@ TriStateTree::State TriStateTree::update(Node* node)
         }
         break;
 
-    case Search::Remove:
+    case Filter::Remove:
         if(leftState == False || rightState == True)
         {
             node->m_state = False;
