@@ -4,7 +4,7 @@
 
 #include "boardsearchdialog.h"
 #include "ui_boardsearchdialog.h"
-#include "search.h"
+#include "filter.h"
 #include "settings.h"
 
 #include <QPushButton>
@@ -28,10 +28,10 @@ BoardSearchDialog::BoardSearchDialog(QWidget *parent) :
     ui->boardView->showMoveIndicator(false);
     ui->boardView->setEnabled(false);
 
-    ui->modeCombo->addItem(tr("Find in current filter"), Search::And);
-    ui->modeCombo->addItem(tr("Search whole database"), Search::NullOperator);
-    ui->modeCombo->addItem(tr("Add to current filter"), Search::Or);
-    ui->modeCombo->addItem(tr("Remove from current filter"), Search::Remove);
+    ui->modeCombo->addItem(tr("Find in current filter"), Filter::And);
+    ui->modeCombo->addItem(tr("Search whole database"), Filter::NullOperator);
+    ui->modeCombo->addItem(tr("Add to current filter"), Filter::Or);
+    ui->modeCombo->addItem(tr("Remove from current filter"), Filter::Remove);
 
     connect(ui->btLeft, SIGNAL(clicked()), SLOT(showPrevBoard()));
     connect(ui->btRight, SIGNAL(clicked()), SLOT(showNextBoard()));
