@@ -6,6 +6,7 @@
 #include "board.h"
 #include "ecopositions.h"
 
+#include <QDataStream>
 #include <QDebug>
 #include <QDir>
 #include <QFile>
@@ -42,10 +43,10 @@ static QMap<quint64, QList<Square> > gtmPositions;
 // then use the Scid internal chess engine to decide which is the "best"
 // move to display to the user.
 //
-void updateFinalGuess(const Board& board, int target, const Move& move)
+void updateFinalGuess(const Board& board, Square target, const Move& move)
 {
-    int from = move.from();
-    int to = move.to();
+    Square from = move.from();
+    Square to = move.to();
 
     QList<Square> data;
     data << from << to;
@@ -62,7 +63,9 @@ void updateFinalGuess(const Board& board, int target, const Move& move)
         }
         int ret = Guess::pickBest(
                       qPrintable(board.toFen()),
-                      from, to, ofrom, oto,
+                      false, /* chess960 not supported */
+                      BitBoard::standardCastlingRooks(),
+                      (Guess::squareT)from, (Guess::squareT)to, (Guess::squareT)ofrom, (Guess::squareT)oto,
                       CALCULATE_MS);
         if(ret == 0)
         {
