@@ -34,7 +34,7 @@ class BoardTheme : public QObject
 {
     Q_OBJECT
 public:
-    enum ColorRole {LightSquare, DarkSquare, Highlight, Frame, CurrentMove, StoredMove, Threat, Target, Check, ColorRoleEndEntry};
+    enum ColorRole {LightSquare, DarkSquare, Highlight, Frame, CurrentMove, StoredMove, Threat, Target, Check, Wall, UnderProtected, ColorRoleEndEntry};
     enum LoadTheme {LoadBoard = 1, LoadPieces = 2, LoadAll = LoadBoard | LoadPieces};
     enum Effects {Plain, Outline = 1, Shadow = 2};
     BoardTheme();
