@@ -16,7 +16,9 @@
 #endif // _MSC_VER
 
 ChartWidget::ChartWidget(QWidget *parent) :
-    QWidget(parent)
+    QWidget(parent),
+    m_ply(0),
+    m_plyIndicator(0)
 {
     setAutoFillBackground(true);
     setUpdatesEnabled(true);
@@ -36,14 +38,13 @@ void ChartWidget::setValues(const QList<double>& values)
         m_values<<d;
     }
     updatePolygon();
-    repaint();
 }
 
 void ChartWidget::setPly(int ply)
 {
     m_ply = ply;
     updatePly();
-    repaint();
+    update();
 }
 
 void ChartWidget::paintEvent(QPaintEvent*)
