@@ -41,7 +41,6 @@ DatabaseList::DatabaseList(QWidget *parent) :
     connect(this, SIGNAL(doubleClicked(const QModelIndex&)), SLOT(slotDoubleClicked(const QModelIndex&)));
     connect(this, SIGNAL(activated(const QModelIndex&)), SLOT(itemSelected(const QModelIndex&)));
     connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), SLOT(slotContextMenu(const QPoint&)));
-    connect(m_filterModel, SIGNAL(rowsInserted(const QModelIndex &, int, int)), SLOT(rowsChanged(const QModelIndex &, int, int)));
     connect(m_model, SIGNAL(OnSelectIndex(const QModelIndex &)), SLOT(slotCurrentIndexChanged(const QModelIndex &)));
 
     setAlternatingRowColors(true);
@@ -205,14 +204,6 @@ void DatabaseList::dbRemoveFromFavorites()
     setFileFavorite(ts, false, 0);
 }
 
-void DatabaseList::rowsChanged(const QModelIndex &, int start, int end)
-{
-    for(int i = start; i <= end; ++i)
-    {
-        setRowHeight(i, 24);
-    }
-}
-
 void DatabaseList::slotMakeBook()
 {
     Q_ASSERT(m_cell.isValid());
@@ -288,7 +279,7 @@ void DatabaseList::dragEnterEvent(QDragEnterEvent *event)
     const GameMimeData* gameMimeData = qobject_cast<const GameMimeData*>(mimeData);
     const DbMimeData* dbMimeData = qobject_cast<const DbMimeData*>(mimeData);
 
-    if(gameMimeData || dbMimeData || event->mimeData()->hasUrls())
+    if(gameMimeData || dbMimeData || (mimeData && mimeData->hasUrls()))
     {
         event->acceptProposedAction();
     }
@@ -321,7 +312,7 @@ void DatabaseList::dropEvent(QDropEvent *event)
         QString s = mimeData->urls().first().toString();
         appendDataBaseToDataBase(event->pos(), s);
     }
-    else if(mimeData->hasUrls())
+    else if(mimeData && mimeData->hasUrls())
     {
         QList<QUrl> urlList = mimeData->urls();
         foreach(QUrl url, urlList)
