@@ -43,6 +43,7 @@ signals:
 
 protected: //Drag'n'Drop Support
     void startToDrag(const QModelIndex&);
+    virtual int minRowHeight() const { return 24; }
 
 protected:
     void startDrag(Qt::DropActions supportedActions);
@@ -67,7 +68,6 @@ private slots:
     void dbOpen();
     void dbToggleUTF8();
     void dbClose();
-    void rowsChanged(const QModelIndex &, int start, int end);
 
 private:
     DatabaseListModel* m_model;
