@@ -39,11 +39,6 @@ FicsConsole::FicsConsole(QWidget *parent, FicsClient* ficsClient) :
     ui->setupUi(this);
     ui->tabWidget->setCurrentIndex(TabMessage);
 
-    m_countDownTimer = new QTimer(this);
-    m_countDownTimer->setInterval(1000);
-    m_countDownTimer->setSingleShot(true);
-    connect(m_countDownTimer, SIGNAL(timeout()), SLOT(SlotCountDownGameTime()));
-
     ui->tabWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
     connect(ui->tabWidget, SIGNAL(customContextMenuRequested(const QPoint&)), SLOT(SlotContextMenu(const QPoint&)));
@@ -116,6 +111,12 @@ FicsConsole::FicsConsole(QWidget *parent, FicsClient* ficsClient) :
     ui->btBoxMessage->addButton(button, QDialogButtonBox::ActionRole);
     connect(button, SIGNAL(clicked()), this, SLOT(SlotSendResign()));
 
+    button = new QToolButton(this);
+    button->setText(tr("Rematch"));
+    button->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    ui->btBoxMessage->addButton(button, QDialogButtonBox::ActionRole);
+    connect(button, SIGNAL(clicked()), SLOT(SlotSendRematch()));
+
     button = new QToolButton(this);
     button->setText(tr("Hint"));
     button->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -222,18 +223,22 @@ void FicsConsole::HandleBoard(int cmd, QString s)
     {
         emit RequestStoredMove();
     }
-    QString timeWhite = l[C64_REMAINDER_TIME_WHITE];
-    QString timeBlack = l[C64_REMAINDER_TIME_BLACK];
-    QTime tw(0,0,0,0);
-    tw = tw.addSecs(timeWhite.toInt());
-    QTime tb(0,0,0,0);
-    tb = tb.addSecs(timeBlack.toInt());
-    ui->timeWhite->setText(tw.toString("h:mm:ss"));
-    ui->timeBlack->setText(tb.toString("h:mm:ss"));
+
+    if (gameMode && !puzzleMode)
+    {
+        QString timeWhite = l[C64_REMAINDER_TIME_WHITE];
+        QString timeBlack = l[C64_REMAINDER_TIME_BLACK];
+        QTime tw(0,0,0,0);
+        tw = tw.addSecs(timeWhite.toInt());
+        QTime tb(0,0,0,0);
+        tb = tb.addSecs(timeBlack.toInt());
+        emit FicsShowTime(White, tw.toString("h:mm:ss"));
+        emit FicsShowTime(Black, tb.toString("h:mm:ss"));
+        emit SignalStartTime(m_bWhiteToMove);
+    }
 }
 
 void FicsConsole::HandleExamineRequest(QListWidgetItem* item)
-
 {
     if (!m_ficsClient) return;
 
@@ -341,7 +346,7 @@ void FicsConsole::SlotSeekTimeChanged(int)
     m_ficsClient->sendCommand("sought");
 }
 
-QString FicsConsole::FormatTime(QString s) const
+QString FicsConsole::DecrementTime(QString s) const
 {
     QString result;
     QTime t = QTime::fromString(s,"h:m:ss");
@@ -370,75 +375,6 @@ QString FicsConsole::FormatTime(QString s) const
     return result;
 }
 
-void FicsConsole::TestTimeWarning(SimpleLabel* label, bool playerToMove)
-{
-    QString s = label->text();
-    label->setText(FormatTime(s));
-    if (playerToMove)
-    {
-        TestTockFor10s(s);
-    }
-    if (TestColor(s,10))
-    {
-       label->setBackgroundColor(Qt::yellow);
-    }
-    else
-    {
-        label->resetBackgroundColor();
-    }
-}
-
-void FicsConsole::SlotCountDownGameTime()
-{
-    if (gameMode)
-    {
-        if (m_bWhiteToMove)
-        {
-            TestTimeWarning(ui->timeWhite, !m_bPlayerIsBlack);
-        }
-        else
-        {
-            TestTimeWarning(ui->timeBlack, m_bPlayerIsBlack);
-        }
-        m_countDownTimer->start();
-    }
-}
-
-bool FicsConsole::TestTockFor10s(QString s)
-{
-#ifdef USE_SOUND
-    if (m_bTockDone)
-    {
-        return true;
-    }
-    QTime t = QTime::fromString(s,"h:m:ss");
-    if (t.msecsSinceStartOfDay()<10000)
-    {
-        if (!m_bFirstTime && AppSettings->getValue("/Sound/Move").toBool())
-        {
-            QSound::play(":/sounds/woodthunk.wav");
-            m_bTockDone = true;
-        }
-        return m_bTockDone;
-    }
-    else
-    {
-        m_bFirstTime = false;
-        return false;
-    }
-#endif
-}
-
-bool FicsConsole::TestColor(QString s, int seconds) const
-{
-    QTime t = QTime::fromString(s,"h:m:ss");
-    if (t.msecsSinceStartOfDay()<seconds*1000)
-    {
-        return true;
-    }
-    return false;
-}
-
 void FicsConsole::SlotSendAccept()
 {
    m_ficsClient->sendCommand("accept");
@@ -478,18 +414,36 @@ void FicsConsole::SlotSendUnexamine()
     m_ficsClient->sendCommand("unexamine");
 }
 
+void FicsConsole::SlotSendRematch()
+{
+    if (!gameMode)
+    {
+        m_ficsClient->sendCommand("rematch");
+    }
+}
+
 void FicsConsole::SlotSendSeek()
 {
     int t = ui->seekTime->value();
     int inc = ui->seekIncrement->value();
     int from = ui->eloMin->value();
     int to = ui->eloMax->value();
+    QString color;
+    if (ui->cbColor->currentIndex() == 0)
+    {
+        color = " w";
+    }
+    else if (ui->cbColor->currentIndex() == 1)
+    {
+        color = " b";
+    }
     if ((t || inc) && (from<=to))
     {
-        QString seek = QString("seek %1 %2 %3 %4-%5 ")
+        QString seek = QString("seek %1 %2 %3%4 %5-%6 ")
                 .arg(t)
                 .arg(inc)
                 .arg(ui->cbRated->currentIndex() ? "unrated" : "rated")
+                .arg(color)
                 .arg(from)
                 .arg(to);
         QListWidgetItem* item = new QListWidgetItem(seek);
@@ -521,6 +475,15 @@ void FicsConsole::UpdateSayCompleter(QString msg)
     }
 }
 
+Color FicsConsole::playerColor() const
+{
+    if (gameMode)
+    {
+        return m_bPlayerIsBlack ? Black : White;
+    }
+    return NoColor;
+}
+
 void FicsConsole::SlotAddNoPlay()
 {
     QString msg = ui->editNoPlay->text();
@@ -655,6 +618,7 @@ void FicsConsole::Disconnected()
     {
         emit RequestGameMode(false);
     }
+    emit FicsShowTimer(false);
     gameMode = false;
     puzzleMode = false;
 }
@@ -742,20 +706,18 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                 }
                 else
                 {
-                    m_countDownTimer->stop();
                     QRegExp wReg("White Clock :([^\\.]*)");
                     if (wReg.indexIn(s) >= 0)
                     {
                         QString w = wReg.cap(1).trimmed();
-                        ui->timeWhite->setText(w);
+                        emit FicsShowTime(White, w);
                     }
                     QRegExp bReg("Black Clock :([^\\.]*)");
                     if (bReg.indexIn(s) >= 0)
                     {
                         QString b = bReg.cap(1).trimmed();
-                        ui->timeBlack->setText(b);
+                        emit FicsShowTime(Black, b);
                     }
-                    m_countDownTimer->start();
                 }
                 break;
             }
@@ -862,8 +824,7 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                 gameMode = true;
                 m_ficsClient->sendCommand("time");
                 m_lastRelation = C64_REL_ISOLATED; // Anything invalid in this context
-                ui->timeWhite->setText(QString());
-                ui->timeBlack->setText(QString());
+                emit FicsShowTimer(true);
                 m_bWhiteToMove = true;
                 emit RequestNewGame();
                 emit RequestGameMode(gameMode);
@@ -875,21 +836,19 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                 {
                     QString w = l[2].remove('(');
                     m_bPlayerIsBlack = w != m_ficsClient->getGuestName();
-                    m_bFirstTime = true;
-                    m_bTockDone = false;
-                    emit SignalPlayerIsBlack(m_bPlayerIsBlack);
+                    emit SignalPlayerIsBlack(m_bPlayerIsBlack, true);
                 }
             }
             break;
         case FicsClient::BLKCMD_INTERNAL_MATCH_END:
             {
                 gameMode = false;
-                m_countDownTimer->stop();
                 ui->textIn->appendPlainText(s);
                 ui->textIn->ensureCursorVisible();
                 emit SignalGameResult(s);
                 emit RequestSaveGame();
                 emit RequestGameMode(gameMode);
+                emit FicsShowTimer(false);
             }
             break;
         case FicsClient::BLKCMD_INTERNAL_GAME_END:
@@ -940,9 +899,7 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
         case FicsClient::BLKCMD_INTERNAL_PUZZLEBOT:
             if (s.contains("kibitzes"))
             {
-                ui->timeWhite->setText(QString());
-                ui->timeBlack->setText(QString());
-
+                emit FicsShowTimer(true);
                 s.remove(QRegExp("puzzlebot[^:]*kibitzes:"));
                 s = s.trimmed();
                 if (!s.contains("tell puzzlebot"))
@@ -959,7 +916,7 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                     {
                         emit RequestGameMode(false);
                     }
-
+                    emit FicsShowTimer(false);
                     puzzleMode = false;
                     SlotSendUnexamine();
                 }
@@ -970,7 +927,7 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                     {
                         emit RequestGameMode(false);
                     }
-
+                    emit FicsShowTimer(false);
                     puzzleMode = false;
                     SlotSendUnexamine();
                 }
@@ -986,11 +943,19 @@ void FicsConsole::HandleMessage(int blockCmd,QString s)
                     }
                     else if (s.startsWith("Black moves"))
                     {
-                        emit SignalPlayerIsBlack(true);
+                        m_bPlayerIsBlack = true;
+                        emit FicsShowTime(Black, "0:00");
+                        emit FicsShowTime(White, "0:00");
+                        emit SignalStartTime(false);
+                        emit SignalPlayerIsBlack(true,false);
                     }
                     else if (s.startsWith("White moves"))
                     {
-                        emit SignalPlayerIsBlack(false);
+                        m_bPlayerIsBlack = false;
+                        emit FicsShowTime(Black, "0:00");
+                        emit FicsShowTime(White, "0:00");
+                        emit SignalStartTime(true);
+                        emit SignalPlayerIsBlack(false,false);
                     }
                 }
             }
