@@ -20,6 +20,7 @@ class QButtonGroup;
 class QTimer;
 class QTableWidgetItem;
 class SimpleLabel;
+class QSound;
 
 enum
 {
@@ -42,6 +43,8 @@ public:
     bool canUsePremove() const;
 
     void saveConfig();
+    Color playerColor() const;
+
 public slots:
     void Terminate();
     void SendMove(QString m);
@@ -72,8 +75,6 @@ protected slots:
     void SlotTabChanged(int tab);
     void SlotSeekTimeChanged(int);
 
-    void SlotCountDownGameTime();
-
     void SlotSendAccept();
     void SlotSendDraw();
     void SlotSendDecline();
@@ -81,6 +82,7 @@ protected slots:
     void SlotSendResign();
     void SlotSendHint();
     void SlotSendUnexamine();
+    void SlotSendRematch();
     void SlotSendSeek();
     void SlotSayMessage();
     void SlotAddNoPlay();
@@ -97,16 +99,16 @@ signals:
     void RequestRemoveLastMove();
     void RequestAddTag(QString tag, QString value);
     void SignalGameResult(QString);
-    void SignalPlayerIsBlack(bool);
+    void SignalPlayerIsBlack(bool,bool);
+    void SignalStartTime(bool);
     void RequestCloseFICS();
     void RequestStoredMove();
 
+    void FicsShowTimer(bool);
+    void FicsShowTime(int, QString);
 protected:
-    QString FormatTime(QString s) const;
+    QString DecrementTime(QString s) const;
     void SetPlayerListItemsFromLine(QString s);
-    bool TestTockFor10s(QString s);
-    bool TestColor(QString s, int seconds) const;
-    void TestTimeWarning(SimpleLabel *label, bool playerToMove);
     void UpdateSayCompleter(QString msg);
 private:
     Ui::FicsConsole *ui;
@@ -115,14 +117,10 @@ private:
     QButtonGroup* btgSeek;
     bool gameMode;
     bool puzzleMode;
-    QTimer* m_countDownTimer;
     bool m_bWhiteToMove;
     Char64Relation m_lastRelation;
     bool m_bPlayerIsBlack;
-    bool m_bTockDone;
-    bool m_bFirstTime;
     int m_prevTab;
-
 };
 
 #endif // FICSCONSOLE_H
