@@ -44,6 +44,11 @@ SimpleLoggingHandler(QtMsgType type, const QMessageLogContext &, const QString &
     case QtWarningMsg:
         logfile << QTime::currentTime().toString().toLatin1().data() << " Warning: "  << msg.toLatin1().data() << endl;
         break;
+#if QT_VERSION > 0x050500
+    case QtInfoMsg:
+        logfile << QTime::currentTime().toString().toLatin1().data() << " Information: " << msg.toLatin1().data() << endl;
+        break;
+#endif
     case QtFatalMsg:
         logfile << QTime::currentTime().toString().toLatin1().data() <<  " Fatal: "   << msg.toLatin1().data() << endl;
         break;
