@@ -460,6 +460,9 @@ MainWindow::MainWindow() : QMainWindow(),
     /* Display main window */
     show();
     downloadManager = new DownloadManager(this);
+    downloadManager2 = new DownloadManager(this);
+    connect(downloadManager2, SIGNAL(onDownloadFinished(QUrl, QString)), this, SLOT(slotDatabaseDroppedHandler(QUrl,QString)), static_cast<Qt::ConnectionType>(Qt::QueuedConnection | Qt::UniqueConnection));
+    connect(downloadManager2, SIGNAL(downloadError(QUrl)), this, SLOT(slotDatabaseDroppedFailed(QUrl)), static_cast<Qt::ConnectionType>(Qt::QueuedConnection | Qt::UniqueConnection));
 
     /* Load files from command line */
     QStringList args = qApp->arguments();
@@ -575,8 +578,6 @@ void MainWindow::closeEvent(QCloseEvent* e)
 {
     if(confirmQuit())
     {
-        m_openingTreeWidget->cancel();
-
         m_recentFiles.save();
         m_databaseList->save();
 
@@ -853,7 +854,7 @@ void MainWindow::updateMenuDatabases()
 void MainWindow::setFavoriteDatabase(QString fname)
 {
     QUrl url = QUrl::fromUserInput(fname);
-    if((url.scheme() == "http") || (url.scheme() == "ftp"))
+    if ((url.scheme() == "http") || (url.scheme() == "https") || (url.scheme() == "ftp") || (url.scheme() == "sftp"))
     {
         m_databaseList->setFileFavorite(fname, true, 0);
     }
@@ -905,7 +906,7 @@ void MainWindow::openDatabaseUrl(QString fname, bool utf8)
     if (!fi.completeSuffix().isEmpty())
     {
         if (url.isValid() && !url.isRelative() &&
-            ((url.scheme() == "http") || (url.scheme() == "https") || (url.scheme() == "ftp")))
+            ((url.scheme() == "http") || (url.scheme() == "https") || (url.scheme() == "ftp") || (url.scheme() == "sftp")))
         {
             slotStatusMessage(tr("Start loading database..."));
             connect(downloadManager, SIGNAL(downloadError(QUrl)), this, SLOT(loadError(QUrl)), static_cast<Qt::ConnectionType>(Qt::QueuedConnection | Qt::UniqueConnection));
@@ -1482,6 +1483,38 @@ void MainWindow::setupActions()
     showThreat->setCheckable(true);
     showThreat->setChecked(AppSettings->getValue("/Board/showThreat").toBool());
 
+    QAction* showAttackW = createAction(tr("Show covered squares from White"), SLOT(slotShowWhiteAttacks()), 0,
+                                       viewToolBar, QIcon(":/images/white_wall.png"));
+    m_menuView->addAction(showAttackW);
+    showAttackW->setCheckable(true);
+    showAttackW->setChecked(false);
+
+    QAction* showAttackB = createAction(tr("Show covered squares from Black"), SLOT(slotShowBlackAttacks()), 0,
+                                       viewToolBar, QIcon(":/images/black_wall.png"));
+    m_menuView->addAction(showAttackB);
+    showAttackB->setCheckable(true);
+    showAttackB->setChecked(false);
+
+    attackGroup = new ExclusiveActionGroup(this);
+    attackGroup->addAction(showAttackW);
+    attackGroup->addAction(showAttackB);
+
+    QAction* showUnderprotectW = createAction(tr("Show underprotected white pieces"), SLOT(slotShowUnderprotectedWhite()), 0,
+                                       viewToolBar, QIcon(":/images/threat_white.png"));
+    m_menuView->addAction(showUnderprotectW);
+    showUnderprotectW->setCheckable(true);
+    showUnderprotectW->setChecked(false);
+
+    QAction* showUnderprotectB = createAction(tr("Show underprotected black pieces"), SLOT(slotShowUnderprotectedBlack()), 0,
+                                       viewToolBar, QIcon(":/images/threat_black.png"));
+    m_menuView->addAction(showUnderprotectB);
+    showUnderprotectB->setCheckable(true);
+    showUnderprotectB->setChecked(false);
+
+    underprotectGroup = new ExclusiveActionGroup(this);
+    underprotectGroup->addAction(showUnderprotectW);
+    underprotectGroup->addAction(showUnderprotectB);
+
     m_menuView->addSeparator();
 
     /* Game menu */
@@ -1765,6 +1798,9 @@ bool MainWindow::confirmQuit()
         }
     }
 
+    cancelPolyglotWriters();
+    m_openingTreeWidget->cancel();
+
     for(int i = m_databases.size() - 1; i; --i)
     {
         slotFileCloseIndex(i);
