@@ -56,6 +56,7 @@ class SaveDialog;
 class TableView;
 class ToolMainWindow;
 class TranslatingSlider;
+class PolyglotWriter;
 
 /**
 @defgroup GUI GUI - User interface components
@@ -371,8 +372,10 @@ public slots:
     void slotMakeBook(QString s);
     /** Show a path in finder */
     void slotShowInFinder(QString path);
+    /** A book was finished with success */
+    void slotBookDone(QString path, PolyglotWriter* writer);
     /** Show a path in finder */
-    void slotBookBuildError(QString path);
+    void slotBookBuildError(QString path, PolyglotWriter *writer);
     /** Merge the clipboard into the current game */
     void slotEditMergePGN();
     /** Create a QImage from the current Board position */
@@ -395,6 +398,8 @@ public slots:
     void SlotDisplayTime(int color, QString t);
     /** Accept Drop of database to a subordinate target */
     void slotDatabaseDropped(QDropEvent*);
+    void slotDatabaseDroppedHandler(QUrl url, QString filename);
+    void slotDatabaseDroppedFailed(QUrl url);
 protected slots:
     /** Update recent files menu */
     void updateMenuDatabases();
@@ -454,6 +459,11 @@ protected slots:
     void slotToggleBrush();
     void slotShowTargetFields();
     void slotShowThreat();
+    void slotShowWhiteAttacks();
+    void slotShowBlackAttacks();
+    void slotShowUnderprotectedWhite();
+    void slotShowUnderprotectedBlack();
+    void cancelPolyglotWriters();
 protected:
     void moveChanged();
     bool pasteFen(QString& errorText, QString fen, bool newGame=false);
@@ -490,6 +500,7 @@ protected:
     QString drawAnnotation() const;
     BoardViewEx *BoardViewFrame();
     void SQAction(QChar c, QAction *action);
+    bool closeDatabaseInfo(DatabaseInfo *aboutToClose);
 signals:
     /** Re-read configuration. */
     void reconfigure();
@@ -570,8 +581,10 @@ private:
     bool loadNextGame();
     /** Save Database without query or progress bar */
     void saveDatabase(DatabaseInfo *dbInfo);
-    /** Save Database with query */
+    /** Save current Database with query */
     bool QuerySaveDatabase();
+    /** Save Database with query */
+    bool QuerySaveDatabase(DatabaseInfo* dbInfo);
     /** Create a new unassociated boardview */
     BoardView* CreateBoardView();
     /** Update Board Information */
@@ -657,6 +670,8 @@ private:
     ExclusiveActionGroup* autoGroup;
     ExclusiveActionGroup* autoGroupTraining;
     ExclusiveActionGroup* brushGroup;
+    ExclusiveActionGroup* attackGroup;
+    ExclusiveActionGroup* underprotectGroup;
     QAction* m_training;
     QAction* m_autoRespond;
     QAction* m_autoPlay;
@@ -666,6 +681,7 @@ private:
     QUndoGroup m_undoGroup;
     QNetworkAccessManager* m_manager;
     DownloadManager* downloadManager;
+    DownloadManager* downloadManager2;
     bool m_machineHasToMove;
     bool m_gameMode;
     FicsClient* m_ficsClient;
@@ -678,6 +694,8 @@ private:
     EngineParameter m_matchParameter;
     bool m_bTrainigAutoRespond;
     bool m_bEvalRequested;
+    QList<PolyglotWriter*> m_polyglotWriters;
+    QMap<QUrl, QString> m_mapDatabaseToDroppedUrl;
 };
 
 #endif
