@@ -11,7 +11,6 @@
 
 #include <QCompleter>
 #include <QStringListModel>
-#include <QToolTip>
 
 #if defined(_MSC_VER) && defined(_DEBUG)
 #define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
@@ -58,6 +57,7 @@ PlayerListWidget::~PlayerListWidget()
 
 void PlayerListWidget::slotReconfigure()
 {
+    ui->tagList->slotReconfigure();
 }
 
 void PlayerListWidget::selectionChangedSlot()
@@ -84,6 +84,10 @@ void PlayerListWidget::findPlayers(const QString& s)
     {
         QStringList newList = m_list.filter(s, Qt::CaseInsensitive);
         m_filterModel->setStringList(newList);
+        if (newList.count()==1)
+        {
+            selectPlayer(newList.at(0));
+        }
     }
 }
 
@@ -190,7 +194,7 @@ void PlayerListWidget::setDatabase(DatabaseInfo* dbInfo)
         m_list = db->index()->playerNames();
     }
     m_list.sort();
-    m_filterModel->setStringList(m_list);
+    findPlayers(ui->filterEdit->text().simplified());
     m_filterModel->sort(0);
 }
 
