@@ -2,11 +2,11 @@
 *   Copyright (C) 2014 by Jens Nissen jens-chessx@gmx.net                   *
 ****************************************************************************/
 
-#include <QtCore>
-
 #ifndef SHELLHELPER_H
 #define SHELLHELPER_H
 
+#include <QString>
+
 class ShellHelper
 {
 public:
