@@ -9,6 +9,7 @@
 
 #include <QAction>
 #include <QApplication>
+#include <QClipboard>
 #include <QHeaderView>
 #include <QMenu>
 
@@ -120,6 +121,17 @@ void TableView::slotReconfigure()
     f.setPointSize(fontSize);
     setFont(f);
 
+    QFontMetrics fm(f);
+    int rowHeight = std::max(minRowHeight(), fm.height()+2);
+
+    QHeaderView *vh = verticalHeader();
+#if QT_VERSION < 0x050000
+    vh->setResizeMode(QHeaderView::Fixed);
+#else
+    vh->sectionResizeMode(QHeaderView::Fixed);
+#endif
+    vh->setDefaultSectionSize(rowHeight);
+
     horizontalHeader()->setSortIndicatorShown(sortIndicator);
     update();
 }
@@ -128,9 +140,12 @@ void TableView::ShowContextMenu(const QPoint& pos)
 {
     QMenu headerMenu;
     QAction* hide = headerMenu.addAction(tr("Hide Column"));
-    headerMenu.addSeparator();
+
     QAction* resizeAll = headerMenu.addAction(tr("Resize visible Columns"));
     QAction* showAll = headerMenu.addAction(tr("Show all Columns"));
+    headerMenu.addSeparator();
+    QAction* copyHTML = headerMenu.addAction(tr("Copy as HTML"));
+    QAction* copyImage = headerMenu.addAction(tr("Copy as Image"));
 
     QAction* selectedItem = headerMenu.exec(mapToGlobal(pos));
     if(selectedItem == hide)
@@ -152,5 +167,99 @@ void TableView::ShowContextMenu(const QPoint& pos)
     {
         resizeColumnsToContents();
     }
+    else if (selectedItem == copyHTML)
+    {
+        QString html = renderToHTML();
+        QApplication::clipboard()->setText(html);
+    }
+    else if (selectedItem == copyImage)
+    {
+        QImage img = renderToImage();
+        QApplication::clipboard()->setImage(img);
+    }
 }
 
+QString TableView::renderHTMLitem(int row,int column) const
+{
+    QString result = "<td>";
+    QVariant data = model()->data(model()->index(row, column));
+    QString s = data.toString();
+    result += s;
+    result += "</td>";
+    return result;
+}
+
+QString TableView::renderHTMLrow(int row) const
+{
+    QString result = "<tr>\n";
+    int columns = model()->columnCount();
+    for (int i=0; i<columns; ++i)
+    {
+        result += renderHTMLitem(row,i);
+    }
+    result += "</tr>\n";
+    return result;
+}
+
+QString TableView::renderHeaderToHTML() const
+{
+    QString result = "<tr>\n";
+    int columns = model()->columnCount();
+    for (int i=0; i<columns; ++i)
+    {
+        result += "<th>";
+        result += horizontalHeader()->model()->headerData(i, Qt::Horizontal).toString();
+        result += "</th>";
+    }
+    result += "</tr>\n";
+    return result;
+}
+
+QString TableView::renderToHTML() const
+{
+    QString result = "<table border='1'>\n";
+    result += renderHeaderToHTML();
+    int rows = model()->rowCount();
+    for (int i=0; i<rows; ++i)
+    {
+        result += renderHTMLrow(i);
+    }
+    result += "</table>\n";
+    return result;
+}
+
+QImage TableView::renderToImage() const
+{
+    QTableView* pTableView = new QTableView;
+    pTableView->setModel(model());
+
+    int width = 0;
+    int height = 0;
+    int columns = model()->columnCount();
+    int rows = model()->rowCount();
+
+    pTableView->resizeColumnsToContents();
+
+    for( int i = 0; i < columns; ++i ) {
+        width += pTableView->columnWidth(i);
+    }
+
+    for( int i = 0; i < rows; ++i ) {
+        height += pTableView->rowHeight(i);
+    }
+
+    height += horizontalHeader()->height();
+
+    pTableView->setFixedSize(width, height);
+    pTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    pTableView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+    QPixmap pixmap(width, height);
+    pixmap.fill();
+
+    pTableView->render(&pixmap);
+    QImage image = pixmap.toImage();
+
+    delete pTableView;
+    return image;
+}
