@@ -841,7 +841,7 @@ void PasteTextEdit::insertUsingMimeData(const QMimeData *source)
 
 bool PasteTextEdit::canInsertFromMimeData(const QMimeData *source) const
 {
-    return source->hasImage() || source->hasUrls() || QTextEdit::canInsertFromMimeData(source);
+    return source && (source->hasImage() || source->hasUrls() || QTextEdit::canInsertFromMimeData(source));
 }
 
 void PasteTextEdit::insertImage(const QImage& image)
@@ -852,6 +852,7 @@ void PasteTextEdit::insertImage(const QImage& image)
 
 void PasteTextEdit::insertFromMimeData(const QMimeData *source)
 {
+    if (!source) return;
     if (source->hasImage())
     {
         insertImage(qvariant_cast<QImage>(source->imageData()));
@@ -869,6 +870,15 @@ void PasteTextEdit::insertFromMimeData(const QMimeData *source)
     }
     else
     {
+        if (source->hasText())
+        {
+            QString s = source->text();
+            if (s.startsWith("<"))
+            {
+                QTextEdit::insertHtml(s);
+                return;
+            }
+        }
         QTextEdit::insertFromMimeData(source);
     }
 }
@@ -882,6 +892,7 @@ void PasteTextEdit::dropImage(const QUrl& url, const QImage& image)
         imageFormat.setWidth( image.width() );
         imageFormat.setHeight( image.height() );
         imageFormat.setName( url.toString() );
+        imageFormat.setBackground(Qt::white);
         textCursor().insertImage(imageFormat);
     }
 }
