@@ -12,7 +12,9 @@
 TranslatingSlider::TranslatingSlider(QWidget *parent) :
     QSlider(parent),
     m_offset(0),
-    m_multiplier(1)
+    m_multiplier(1),
+    m_start2(INT_MAX),
+    m_multiplier2(1)
 {
     connect(this, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
 }
@@ -39,16 +41,46 @@ void TranslatingSlider::setOffset(int offset)
 
 void TranslatingSlider::slotValueChanged(int value)
 {
-    emit translatedValueChanged(value*m_multiplier + m_offset);
+    emit translatedValueChanged(translateValue(value));
+}
+
+void TranslatingSlider::setMultiplier2(int multiplier2)
+{
+    m_multiplier2 = multiplier2;
+}
+
+void TranslatingSlider::setStart2(int start2)
+{
+    m_start2 = start2;
 }
 
 void TranslatingSlider::setTranslatedValue(int value)
 {
-    setValue((value-m_offset)/m_multiplier);
+    if (value > m_offset + m_start2*m_multiplier)
+    {
+        value -= m_offset;
+        int v = value - m_start2*m_multiplier;
+        setValue(m_start2 + v/m_multiplier2);
+    }
+    else
+    {
+        setValue((value-m_offset)/m_multiplier);
+    }
 }
 
 int TranslatingSlider::translatedValue() const
 {
-    int v = value();
-    return (v*m_multiplier + m_offset);
+    return translateValue(value());
+}
+
+int TranslatingSlider::translateValue(int v) const
+{
+    if (v<=m_start2)
+    {
+        return (v*m_multiplier + m_offset);
+    }
+    else
+    {
+        return m_offset + m_start2*m_multiplier + ((v-m_start2)*m_multiplier2);
+    }
 }
