@@ -31,6 +31,10 @@
 #   include <errno.h>
 #endif
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
 
 #ifndef local
 #  define local static
